@@ -5,22 +5,25 @@ Created on Fri Nov 19 18:29:16 2021
 
 """
 
-
 def cry_out2pmg(output, initial=False, vacuum=10):
+    #Transform a CRYSTAL output object into a pymatgen structure object
+
     # output_file is a crystal output object
+    # initial == False reads the last geometry of the output file
+    # vacuum needs to be specified because pymatgen does not have 2D symmetry tools
     
-    from pymatgen.core import Structure
-    from crystal_functions.file_readwrite import get_dimensionality    
+    from pymatgen.core import Structure  
     import numpy as np
 
+    #Extract information from the output file
     dimensionality = output.get_dimensionality()
-    output.get_last_geom(write_gui_file=False, print_cart=False)
-    output.get_lattice(initial=initial)
+    output.get_last_geom(write_gui_file=False)
+    output.get_primitive_lattice(initial=initial)
     
     if dimensionality == 3:
         structure = Structure(output.primitive_lattice, output.atom_numbers, 
                               output.atom_positions_cart, coords_are_cartesian=True)
-        
+    # Add vacuum for 2D structures    
     elif dimensionality == 2:
         thickness = np.amax(np.array(output.atom_positions_cart)[:, 2]) - \
                     np.amin(np.array(output.atom_positions_cart)[:, 2])
@@ -33,45 +36,37 @@ def cry_out2pmg(output, initial=False, vacuum=10):
     
     return structure
 
-    
-'''###TESTING
-cry_out2pmg('examples/data/mgo.out')'''
-
 
 def cry_bands2pmg(output, bands, labels=None):
-    # WORK IN PROGRESS Function to transform a crystal band file into a pmg band object Format of the pmg object:
-    # classBandStructure(kpoints, eigenvals, lattice, efermi, labels_dict=None, coords_are_cartesian=False,
-    # structure=None, projections=None)
+    # WORK IN TRANSFORMATION
+    #Transform a CRYSTAL bands object into a pymatgen bands object
+
+    # output_file is a crystal output object
+    # bands is a crystal bands object
+        # classBandStructure(kpoints, eigenvals, lattice, efermi, labels_dict=None, coords_are_cartesian=False,
+        # structure=None, projections=None)
+    # labels are the k point labels to display in the band structure
     
     import numpy as np
     from pymatgen.electronic_structure.bandstructure import BandStructureSymmLine
     
     from pymatgen.core.lattice import Lattice
     from pymatgen.electronic_structure.core import Spin
-
-    output.reciprocal_lattice()
+    
+    # Read the reciprocal lattice from the output file
+    output.get_reciprocal_lattice()
     labels_dict = {}
     
     if labels is not None:
         for i, j in enumerate(bands.n_points):
             labels_dict[labels[i]] = bands.k_point_coordinates[j-1]
     
-    '''#This defines the Kpoint objects. Not needed at the moment, but might be useful in the future
-    k_points = []
-    for i, coord in enumerate(bands.k_point_coordinates):
-        k_points.append(Kpoint(np.array(coord), 
-                               Lattice(output.reciprocal_vectors)))
-        if len(bands.n_points) > 1:
-            if i+1 in bands.n_points[1:-1]:
-                print(i+1)
-                k_points.append(Kpoint(np.array(coord), 
-                               Lattice(output.reciprocal_vectors)))'''
     
     # List of k points coordinates as symmetry lines
     band_energy = bands.bands 
     
     # pymatgen will plot the bands wrt to the Fermi Energy
-    band_energy[1:, :, :] = band_energy[1:, :, :] + output.fermi_energy()
+    band_energy[1:, :, :] = band_energy[1:, :, :] + output.get_fermi_energy()
     k_points_coordinates = []
     
     for i, coord in enumerate(bands.k_point_coordinates):
@@ -91,36 +86,20 @@ def cry_bands2pmg(output, bands, labels=None):
         eigenvals[Spin.down] = band_energy[:, :, 1]
 
     return BandStructureSymmLine(k_points_coordinates, eigenvals, 
-                                 Lattice(output.reciprocal_vectors), 
+                                 Lattice(output.reciprocal_lattice), 
                                  bands.efermi, labels_dict,
                                  coords_are_cartesian=False)
     
-from crystal_functions.file_readwrite import Crystal_output, Crystal_properties
-from crystal_functions.convert import cry_bands2pmg
 
-'''cry_output = Crystal_output('../examples/data/mgo_optgeom.out')
-cry_bands = Crystal_bands('../examples/data/mgo_BAND_dat.BAND')
-bs = cry_bands2pmg(cry_output,cry_bands,labels=['\\Gamma','B','C','\\Gamma','E'])'''
+def cry_gui2pmg(gui_file,vacuum=10):
+    #Transform a CRYSTAL structure (gui) file into a pymatgen bands object
 
-'''###TESTING
-from cry_file_readwrite import Crystal_bands, Crystal_output
-from pymatgen.core.lattice import Lattice
-
-mgo_bands = Crystal_bands('examples/data/mgo_SPIN_BAND_dat.BAND')
-mgo_out = Crystal_output('examples/data/mgo_SPIN.out')
-#print(mgo_bands.n_points,labels=['A','B','C','D','E'])
-#mgo_out.reciprocal_lattice()
-
-
-#cry_bands2pmg(bands,output_name)
-#mgo_output_name = 'data/mgo_BAND.outp'
-cry_bands2pmg(mgo_out,mgo_bands,labels=['A','B','C','D','E'])'''
-
-
-def cry_gui2pmg(gui_file):
+    #gui_file is the CRYSTAL structure (gui) file
+    # vacuum needs to be specified because pymatgen does not have 2D symmetry tools
 
     from pymatgen.core.structure import Structure
     import sys
+    import numpy as np
 
     try:
         if gui_file[-3:] != 'gui' and gui_file[-3:] != 'f34':
@@ -131,32 +110,47 @@ def cry_gui2pmg(gui_file):
     except:
         print('EXITING: a .gui file needs to be specified')
         sys.exit(1)
-    if data[0].split()[0] == '3':
-        lattice = []
-        for i in range(1, 4):
-            lattice.append([float(x) for x in data[i].split()])
-        n_symmops = int(data[4].split()[0])
-        n_atoms = int(data[5+n_symmops*4].split()[0])
-        atom_number = []
-        atom_positions = []
-        for i in range(6+n_symmops*4, 6+n_symmops*4+n_atoms):
-            atom_line = data[i].split()
-            atom_number.append(str(atom_line[0]))
-            atom_positions.append([float(x) for x in atom_line[1:]])
+    
+    lattice = []
+    for i in range(1, 4):
+        lattice.append([float(x) for x in data[i].split()])
+    n_symmops = int(data[4].split()[0])
+    n_atoms = int(data[5+n_symmops*4].split()[0])
+    atom_number = []
+    atom_positions = []
+    for i in range(6+n_symmops*4, 6+n_symmops*4+n_atoms):
+        atom_line = data[i].split()
+        atom_number.append(str(atom_line[0]))
+        atom_positions.append([float(x) for x in atom_line[1:]])
 
-        return Structure(lattice, atom_number, atom_positions, coords_are_cartesian=True)
-
-    else:
-        return 'Lower dimensionality not yet implemented'
+    if data[0].split()[0] == '2':
+        thickness = np.amax(np.array(atom_positions)[:, 2]) - \
+                    np.amin(np.array(atom_positions)[:, 2])
+        
+        lattice[2][2] = thickness + vacuum
+    
+    return Structure(lattice, atom_number, atom_positions, coords_are_cartesian=True)
+        
 
     
 def cry_out2ase(output, initial=False, dimensionality=3, vacuum=10):
+    #Transform a CRYSTAL output object into an ASE bands object
+    #The gui file is firt transfomed into a pymatgen object
+
+    # output_file is a crystal output object
+    # initial == False reads the last geometry of the output file
+    # dimensionality is the dimensionality of the system  
+    # vacuum needs to be specified because pymatgen does not have 2D symmetry tools
 
     from pymatgen.io.ase import AseAtomsAdaptor
 
     return AseAtomsAdaptor().get_atoms(cry_out2pmg(output,initial=initial,dimensionality=dimensionality,vacuum=vacuum))
 
 def cry_gui2ase(gui_file):
+    #Transform a CRYSTAL structure (gui) file into an ASE bands object
+    #The gui file is firt transfomed into a pymatgen object
+
+    #gui_file is the CRYSTAL structure (gui) file
 
     from pymatgen.io.ase import AseAtomsAdaptor
 
